@@ -7,7 +7,7 @@ use Digest::MD5::File qw(file_md5 file_md5_hex);
 use File::stat;
 use MIME::Base64;
 use Moose::Util::TypeConstraints;
-use MooseX::Types::DateTimeX qw( DateTime );
+use MooseX::Types::DateTime::MoreCoercions qw( DateTime );
 
 enum 'AclShort' =>
     qw(private public-read public-read-write authenticated-read);
